{
    **schema_registry.get("test_base"),
    "entrée": {
        "required": False,
        "type": ["string", "integer"],
        "nullable": False,
    },
    "params": {
        "required": False,
        "type": ["string", "integer"],
        "nullable": False,
    },
}
